==> zio-aws-amplifybackend_2.12-5.17.150.1-sources.jar: zio/aws/amplifybackend/model/DeleteTokenResponse.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__boolean
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteTokenResponse(isSuccess: Option[__boolean] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.DeleteTokenResponse = {
    import DeleteTokenResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.DeleteTokenResponse
      .builder()
      .optionallyWith(isSuccess.map(value => value: java.lang.Boolean))(
        _.isSuccess
      )
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.DeleteTokenResponse.ReadOnly =
    zio.aws.amplifybackend.model.DeleteTokenResponse.wrap(buildAwsValue())
}
object DeleteTokenResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.DeleteTokenResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.DeleteTokenResponse =
      zio.aws.amplifybackend.model
        .DeleteTokenResponse(isSuccess.map(value => value))
    def isSuccess: Option[__boolean]
    def getIsSuccess: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("isSuccess", isSuccess)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteTokenResponse
  ) extends zio.aws.amplifybackend.model.DeleteTokenResponse.ReadOnly {
    override val isSuccess: Option[__boolean] =
      scala.Option(impl.isSuccess()).map(value => value: __boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteTokenResponse
  ): zio.aws.amplifybackend.model.DeleteTokenResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-amplifybackend_2.13-5.17.125.1-sources.jar: zio/aws/amplifybackend/model/DeleteTokenResponse.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__boolean
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteTokenResponse(isSuccess: Option[__boolean] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.DeleteTokenResponse = {
    import DeleteTokenResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.DeleteTokenResponse
      .builder()
      .optionallyWith(
        isSuccess.map(value => __boolean.unwrap(value): java.lang.Boolean)
      )(_.isSuccess)
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.DeleteTokenResponse.ReadOnly =
    zio.aws.amplifybackend.model.DeleteTokenResponse.wrap(buildAwsValue())
}
object DeleteTokenResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.DeleteTokenResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.DeleteTokenResponse =
      zio.aws.amplifybackend.model
        .DeleteTokenResponse(isSuccess.map(value => value))
    def isSuccess: Option[__boolean]
    def getIsSuccess: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("isSuccess", isSuccess)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteTokenResponse
  ) extends zio.aws.amplifybackend.model.DeleteTokenResponse.ReadOnly {
    override val isSuccess: Option[__boolean] = scala
      .Option(impl.isSuccess())
      .map(value => zio.aws.amplifybackend.model.primitives.__boolean(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteTokenResponse
  ): zio.aws.amplifybackend.model.DeleteTokenResponse.ReadOnly = new Wrapper(
    impl
  )
}
